# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages.proto',
  package='robotc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0emessages.proto\x12\x06robotc\"\x17\n\x08Response\x12\x0b\n\x03ret\x18\x01 \x01(\x05\"-\n\nCoordinate\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"+\n\x08Rotation\x12\t\n\x01r\x18\x01 \x01(\x01\x12\t\n\x01p\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\"N\n\x02PR\x12$\n\x08position\x18\x01 \x01(\x0b\x32\x12.robotc.Coordinate\x12\"\n\x08rotation\x18\x02 \x01(\x0b\x32\x10.robotc.Rotation\"\x17\n\x05JPose\x12\x0e\n\x06joints\x18\x01 \x03(\x01\"8\n\x07Payload\x12\x0c\n\x04mass\x18\x01 \x01(\x01\x12\x1f\n\x03\x63og\x18\x02 \x01(\x0b\x32\x12.robotc.Coordinate\"\x1b\n\x0bPayloadMass\x12\x0c\n\x04mass\x18\x01 \x01(\x01\"-\n\nPayloadCog\x12\x1f\n\x03\x63og\x18\x01 \x01(\x0b\x32\x12.robotc.Coordinate\"\x14\n\x05IOPin\x12\x0b\n\x03pin\x18\x01 \x01(\x05\"!\n\x03\x44IO\x12\x0b\n\x03pin\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\"/\n\x03\x41IO\x12\x0b\n\x03pin\x18\x01 \x01(\x05\x12\x0c\n\x04mode\x18\x02 \x01(\x05\x12\r\n\x05value\x18\x03 \x01(\x01\"2\n\x15ModbusExternalIOState\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x05\"\xfe\x01\n\x02IO\x12\x1f\n\nrobotDIOIn\x18\x01 \x03(\x0b\x32\x0b.robotc.DIO\x12 \n\x0brobotDIOOut\x18\x02 \x03(\x0b\x32\x0b.robotc.DIO\x12\x1f\n\nrobotAIOIn\x18\x03 \x03(\x0b\x32\x0b.robotc.AIO\x12 \n\x0brobotAIOOut\x18\x04 \x03(\x0b\x32\x0b.robotc.AIO\x12\x1d\n\x08tcpDIOIn\x18\x05 \x03(\x0b\x32\x0b.robotc.DIO\x12\x1e\n\ttcpDIOOut\x18\x06 \x03(\x0b\x32\x0b.robotc.DIO\x12\x33\n\x0c\x65xtIODevices\x18\x07 \x03(\x0b\x32\x1d.robotc.ModbusExternalIOState\"=\n\x08Hardware\x12\r\n\x05model\x18\x01 \x01(\t\x12\n\n\x02sn\x18\x02 \x01(\t\x12\x16\n\x0e\x64river_version\x18\x03 \x01(\t\"\xa1\x02\n\tRobotInfo\x12\x1f\n\x05robot\x18\x01 \x01(\x0b\x32\x10.robotc.Hardware\x12 \n\x06\x66lange\x18\x02 \x01(\x0b\x32\x10.robotc.Hardware\x12\x1d\n\x03led\x18\x03 \x01(\x0b\x32\x10.robotc.Hardware\x12 \n\x06joints\x18\x04 \x03(\x0b\x32\x10.robotc.Hardware\x12\x11\n\trcVersion\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\"\n\x08\x63omboard\x18\x07 \x01(\x0b\x32\x10.robotc.Hardware\x12\x0b\n\x03mac\x18\x08 \x01(\t\x12\x1d\n\x03\x61rm\x18\t \x01(\x0b\x32\x10.robotc.Hardware\x12\x0e\n\x06\x61ppTag\x18\n \x01(\t\x12\x0f\n\x07typeTag\x18\x0b \x01(\t\"A\n\nDeviceInfo\x12!\n\x07\x64\x65vInfo\x18\x01 \x01(\x0b\x32\x10.robotc.Hardware\x12\x10\n\x08\x64\x65v_type\x18\x02 \x01(\x05*[\n\x08LuaState\x12\x08\n\x04IDLE\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\t\n\x05\x42\x45GIN\x10\x05\x12\x07\n\x03\x45ND\x10\x06\x62\x06proto3'
)

_LUASTATE = _descriptor.EnumDescriptor(
  name='LuaState',
  full_name='robotc.LuaState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IDLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEGIN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='END', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1219,
  serialized_end=1310,
)
_sym_db.RegisterEnumDescriptor(_LUASTATE)

LuaState = enum_type_wrapper.EnumTypeWrapper(_LUASTATE)
IDLE = 0
RUNNING = 1
PAUSED = 2
ABORTED = 3
STOPPED = 4
BEGIN = 5
END = 6



_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='robotc.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='robotc.Response.ret', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=49,
)


_COORDINATE = _descriptor.Descriptor(
  name='Coordinate',
  full_name='robotc.Coordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='robotc.Coordinate.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='robotc.Coordinate.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='robotc.Coordinate.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=96,
)


_ROTATION = _descriptor.Descriptor(
  name='Rotation',
  full_name='robotc.Rotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='robotc.Rotation.r', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='robotc.Rotation.p', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='robotc.Rotation.y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=141,
)


_PR = _descriptor.Descriptor(
  name='PR',
  full_name='robotc.PR',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='robotc.PR.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='robotc.PR.rotation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=221,
)


_JPOSE = _descriptor.Descriptor(
  name='JPose',
  full_name='robotc.JPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.JPose.joints', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=246,
)


_PAYLOAD = _descriptor.Descriptor(
  name='Payload',
  full_name='robotc.Payload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mass', full_name='robotc.Payload.mass', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cog', full_name='robotc.Payload.cog', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=304,
)


_PAYLOADMASS = _descriptor.Descriptor(
  name='PayloadMass',
  full_name='robotc.PayloadMass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mass', full_name='robotc.PayloadMass.mass', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=333,
)


_PAYLOADCOG = _descriptor.Descriptor(
  name='PayloadCog',
  full_name='robotc.PayloadCog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cog', full_name='robotc.PayloadCog.cog', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=380,
)


_IOPIN = _descriptor.Descriptor(
  name='IOPin',
  full_name='robotc.IOPin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.IOPin.pin', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=402,
)


_DIO = _descriptor.Descriptor(
  name='DIO',
  full_name='robotc.DIO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.DIO.pin', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.DIO.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=437,
)


_AIO = _descriptor.Descriptor(
  name='AIO',
  full_name='robotc.AIO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.AIO.pin', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='robotc.AIO.mode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.AIO.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=486,
)


_MODBUSEXTERNALIOSTATE = _descriptor.Descriptor(
  name='ModbusExternalIOState',
  full_name='robotc.ModbusExternalIOState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ModbusExternalIOState.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='robotc.ModbusExternalIOState.state', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=538,
)


_IO = _descriptor.Descriptor(
  name='IO',
  full_name='robotc.IO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robotDIOIn', full_name='robotc.IO.robotDIOIn', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotDIOOut', full_name='robotc.IO.robotDIOOut', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotAIOIn', full_name='robotc.IO.robotAIOIn', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robotAIOOut', full_name='robotc.IO.robotAIOOut', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcpDIOIn', full_name='robotc.IO.tcpDIOIn', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcpDIOOut', full_name='robotc.IO.tcpDIOOut', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extIODevices', full_name='robotc.IO.extIODevices', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=795,
)


_HARDWARE = _descriptor.Descriptor(
  name='Hardware',
  full_name='robotc.Hardware',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='robotc.Hardware.model', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sn', full_name='robotc.Hardware.sn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_version', full_name='robotc.Hardware.driver_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=858,
)


_ROBOTINFO = _descriptor.Descriptor(
  name='RobotInfo',
  full_name='robotc.RobotInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robot', full_name='robotc.RobotInfo.robot', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flange', full_name='robotc.RobotInfo.flange', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led', full_name='robotc.RobotInfo.led', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.RobotInfo.joints', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcVersion', full_name='robotc.RobotInfo.rcVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='robotc.RobotInfo.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comboard', full_name='robotc.RobotInfo.comboard', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='robotc.RobotInfo.mac', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arm', full_name='robotc.RobotInfo.arm', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appTag', full_name='robotc.RobotInfo.appTag', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typeTag', full_name='robotc.RobotInfo.typeTag', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=1150,
)


_DEVICEINFO = _descriptor.Descriptor(
  name='DeviceInfo',
  full_name='robotc.DeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devInfo', full_name='robotc.DeviceInfo.devInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dev_type', full_name='robotc.DeviceInfo.dev_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1152,
  serialized_end=1217,
)

_PR.fields_by_name['position'].message_type = _COORDINATE
_PR.fields_by_name['rotation'].message_type = _ROTATION
_PAYLOAD.fields_by_name['cog'].message_type = _COORDINATE
_PAYLOADCOG.fields_by_name['cog'].message_type = _COORDINATE
_IO.fields_by_name['robotDIOIn'].message_type = _DIO
_IO.fields_by_name['robotDIOOut'].message_type = _DIO
_IO.fields_by_name['robotAIOIn'].message_type = _AIO
_IO.fields_by_name['robotAIOOut'].message_type = _AIO
_IO.fields_by_name['tcpDIOIn'].message_type = _DIO
_IO.fields_by_name['tcpDIOOut'].message_type = _DIO
_IO.fields_by_name['extIODevices'].message_type = _MODBUSEXTERNALIOSTATE
_ROBOTINFO.fields_by_name['robot'].message_type = _HARDWARE
_ROBOTINFO.fields_by_name['flange'].message_type = _HARDWARE
_ROBOTINFO.fields_by_name['led'].message_type = _HARDWARE
_ROBOTINFO.fields_by_name['joints'].message_type = _HARDWARE
_ROBOTINFO.fields_by_name['comboard'].message_type = _HARDWARE
_ROBOTINFO.fields_by_name['arm'].message_type = _HARDWARE
_DEVICEINFO.fields_by_name['devInfo'].message_type = _HARDWARE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Coordinate'] = _COORDINATE
DESCRIPTOR.message_types_by_name['Rotation'] = _ROTATION
DESCRIPTOR.message_types_by_name['PR'] = _PR
DESCRIPTOR.message_types_by_name['JPose'] = _JPOSE
DESCRIPTOR.message_types_by_name['Payload'] = _PAYLOAD
DESCRIPTOR.message_types_by_name['PayloadMass'] = _PAYLOADMASS
DESCRIPTOR.message_types_by_name['PayloadCog'] = _PAYLOADCOG
DESCRIPTOR.message_types_by_name['IOPin'] = _IOPIN
DESCRIPTOR.message_types_by_name['DIO'] = _DIO
DESCRIPTOR.message_types_by_name['AIO'] = _AIO
DESCRIPTOR.message_types_by_name['ModbusExternalIOState'] = _MODBUSEXTERNALIOSTATE
DESCRIPTOR.message_types_by_name['IO'] = _IO
DESCRIPTOR.message_types_by_name['Hardware'] = _HARDWARE
DESCRIPTOR.message_types_by_name['RobotInfo'] = _ROBOTINFO
DESCRIPTOR.message_types_by_name['DeviceInfo'] = _DEVICEINFO
DESCRIPTOR.enum_types_by_name['LuaState'] = _LUASTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Response)
  })
_sym_db.RegisterMessage(Response)

Coordinate = _reflection.GeneratedProtocolMessageType('Coordinate', (_message.Message,), {
  'DESCRIPTOR' : _COORDINATE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Coordinate)
  })
_sym_db.RegisterMessage(Coordinate)

Rotation = _reflection.GeneratedProtocolMessageType('Rotation', (_message.Message,), {
  'DESCRIPTOR' : _ROTATION,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Rotation)
  })
_sym_db.RegisterMessage(Rotation)

PR = _reflection.GeneratedProtocolMessageType('PR', (_message.Message,), {
  'DESCRIPTOR' : _PR,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.PR)
  })
_sym_db.RegisterMessage(PR)

JPose = _reflection.GeneratedProtocolMessageType('JPose', (_message.Message,), {
  'DESCRIPTOR' : _JPOSE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JPose)
  })
_sym_db.RegisterMessage(JPose)

Payload = _reflection.GeneratedProtocolMessageType('Payload', (_message.Message,), {
  'DESCRIPTOR' : _PAYLOAD,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Payload)
  })
_sym_db.RegisterMessage(Payload)

PayloadMass = _reflection.GeneratedProtocolMessageType('PayloadMass', (_message.Message,), {
  'DESCRIPTOR' : _PAYLOADMASS,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.PayloadMass)
  })
_sym_db.RegisterMessage(PayloadMass)

PayloadCog = _reflection.GeneratedProtocolMessageType('PayloadCog', (_message.Message,), {
  'DESCRIPTOR' : _PAYLOADCOG,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.PayloadCog)
  })
_sym_db.RegisterMessage(PayloadCog)

IOPin = _reflection.GeneratedProtocolMessageType('IOPin', (_message.Message,), {
  'DESCRIPTOR' : _IOPIN,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.IOPin)
  })
_sym_db.RegisterMessage(IOPin)

DIO = _reflection.GeneratedProtocolMessageType('DIO', (_message.Message,), {
  'DESCRIPTOR' : _DIO,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DIO)
  })
_sym_db.RegisterMessage(DIO)

AIO = _reflection.GeneratedProtocolMessageType('AIO', (_message.Message,), {
  'DESCRIPTOR' : _AIO,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.AIO)
  })
_sym_db.RegisterMessage(AIO)

ModbusExternalIOState = _reflection.GeneratedProtocolMessageType('ModbusExternalIOState', (_message.Message,), {
  'DESCRIPTOR' : _MODBUSEXTERNALIOSTATE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ModbusExternalIOState)
  })
_sym_db.RegisterMessage(ModbusExternalIOState)

IO = _reflection.GeneratedProtocolMessageType('IO', (_message.Message,), {
  'DESCRIPTOR' : _IO,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.IO)
  })
_sym_db.RegisterMessage(IO)

Hardware = _reflection.GeneratedProtocolMessageType('Hardware', (_message.Message,), {
  'DESCRIPTOR' : _HARDWARE,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Hardware)
  })
_sym_db.RegisterMessage(Hardware)

RobotInfo = _reflection.GeneratedProtocolMessageType('RobotInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTINFO,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RobotInfo)
  })
_sym_db.RegisterMessage(RobotInfo)

DeviceInfo = _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEINFO,
  '__module__' : 'messages_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DeviceInfo)
  })
_sym_db.RegisterMessage(DeviceInfo)


# @@protoc_insertion_point(module_scope)
